package cn.wustlinghang.wusthelper.internal.undergrad.services;

import cn.wustlinghang.mywust.core.parser.undergraduate.*;
import cn.wustlinghang.mywust.data.global.Course;
import cn.wustlinghang.mywust.data.global.Score;
import cn.wustlinghang.mywust.data.global.StudentInfo;
import cn.wustlinghang.mywust.data.undergrad.ExamDelayApplication;
import cn.wustlinghang.mywust.exception.ParseException;
import jakarta.enterprise.context.ApplicationScoped;

import java.util.List;

@ApplicationScoped
public class ParseService {
    private final UndergradCourseTableParser courseTableParser;
    private final UndergradScoreParser scoreParser;
    private final UndergradStudentInfoPageParser studentInfoPageParser;
    private final UndergradTrainingPlanPageParser trainingPlanPageParser;
    private final UndergradCreditStatusParser creditStatusParser;
    private final UndergradExamDelayParser examDelayParser;

    public ParseService(UndergradCourseTableParser courseTableParser,
                        UndergradScoreParser scoreParser,
                        UndergradStudentInfoPageParser studentInfoPageParser,
                        UndergradTrainingPlanPageParser trainingPlanPageParser,
                        UndergradCreditStatusParser creditStatusParser,
                        UndergradExamDelayParser examDelayParser) {

        this.courseTableParser = courseTableParser;
        this.scoreParser = scoreParser;
        this.studentInfoPageParser = studentInfoPageParser;
        this.trainingPlanPageParser = trainingPlanPageParser;
        this.creditStatusParser = creditStatusParser;
        this.examDelayParser = examDelayParser;
    }

    public List<Course> parseCourseTable(String data) throws ParseException {
        return courseTableParser.parse(data);
    }

    public List<Score> parseScore(String data) throws ParseException {
        return scoreParser.parse(data);
    }

    public StudentInfo parseStudentInfo(String data) throws ParseException {
        return studentInfoPageParser.parse(data);
    }

    public String parseTrainingPlan(String data) throws ParseException {
        return trainingPlanPageParser.parse(data);
    }

    public String parseCreditStatus(String data) throws ParseException {
        return creditStatusParser.parse(data);
    }

    public List<ExamDelayApplication> parseExamDelayApplications(String data) throws ParseException {
        return examDelayParser.parse(data);
    }
}
